@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DataArchiveFile(
-    cdktf.TerraformDataSource,
+    _cdktf_9a9027ec.TerraformDataSource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-archive.dataArchiveFile.DataArchiveFile",
 ):
@@ -30,7 +30,7 @@ class DataArchiveFile(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         output_path: builtins.str,
@@ -38,18 +38,18 @@ class DataArchiveFile(
         excludes: typing.Optional[typing.Sequence[builtins.str]] = None,
         id: typing.Optional[builtins.str] = None,
         output_file_mode: typing.Optional[builtins.str] = None,
-        source: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["DataArchiveFileSource", typing.Dict[str, typing.Any]]]]] = None,
+        source: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["DataArchiveFileSource", typing.Dict[builtins.str, typing.Any]]]]] = None,
         source_content: typing.Optional[builtins.str] = None,
         source_content_filename: typing.Optional[builtins.str] = None,
         source_dir: typing.Optional[builtins.str] = None,
         source_file: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/archive/d/file archive_file} Data Source.
 
@@ -74,7 +74,7 @@ class DataArchiveFile(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataArchiveFile.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__3f8174f229f3604133f5c77a80cd25d2977aef1687fff32139249b73dce43cf7)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataArchiveFileConfig(
@@ -102,13 +102,13 @@ class DataArchiveFile(
     @jsii.member(jsii_name="putSource")
     def put_source(
         self,
-        value: typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["DataArchiveFileSource", typing.Dict[str, typing.Any]]]],
+        value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["DataArchiveFileSource", typing.Dict[builtins.str, typing.Any]]]],
     ) -> None:
         '''
         :param value: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataArchiveFile.put_source)
+            type_hints = typing.get_type_hints(_typecheckingstub__d003f85638c28bffbd4441abb65c0dc94b23f40ab53f06c48a8d24b28d5f42be)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putSource", [value]))
 
@@ -222,8 +222,8 @@ class DataArchiveFile(
     @jsii.member(jsii_name="sourceInput")
     def source_input(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataArchiveFileSource"]]]:
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataArchiveFileSource"]]], jsii.get(self, "sourceInput"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["DataArchiveFileSource"]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["DataArchiveFileSource"]]], jsii.get(self, "sourceInput"))
 
     @builtins.property
     @jsii.member(jsii_name="typeInput")
@@ -238,7 +238,7 @@ class DataArchiveFile(
     @excludes.setter
     def excludes(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFile, "excludes").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__20c4285397b574ace2586d5b7d9c0efed97c37db7016848d04cb03aa64878453)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "excludes", value)
 
@@ -250,7 +250,7 @@ class DataArchiveFile(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFile, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__432198c6c939e380c074357e6b59c80d61ade9150c5df2056d07049c2715bcf6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -262,7 +262,7 @@ class DataArchiveFile(
     @output_file_mode.setter
     def output_file_mode(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFile, "output_file_mode").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5cf0d3fbf6707bec587f4a960cd54edd8e60f917d78b8b942cc183e29c7291d2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "outputFileMode", value)
 
@@ -274,7 +274,7 @@ class DataArchiveFile(
     @output_path.setter
     def output_path(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFile, "output_path").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__3592643f4a565fac9e7ff8c5189ac2f818943f620f705989325f0070d0f74749)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "outputPath", value)
 
@@ -286,7 +286,7 @@ class DataArchiveFile(
     @source_content.setter
     def source_content(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFile, "source_content").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d4f7f1c2a67ef2d6cd3380e72c2663d13a07e8a175ff5a4cf7f68c4df802c472)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceContent", value)
 
@@ -298,7 +298,7 @@ class DataArchiveFile(
     @source_content_filename.setter
     def source_content_filename(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFile, "source_content_filename").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__26ddff38facb63d2db815fde82cff0e0559b482fd07b09a7c023eac38911966c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceContentFilename", value)
 
@@ -310,7 +310,7 @@ class DataArchiveFile(
     @source_dir.setter
     def source_dir(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFile, "source_dir").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__f9dfe185d1160c0d01df7661702ee3e6ce0223ba9ffbf6fe85f7c82315c1702f)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceDir", value)
 
@@ -322,7 +322,7 @@ class DataArchiveFile(
     @source_file.setter
     def source_file(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFile, "source_file").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0cb49ee8a8a77e542ce50503f7116ae685411f0a635d0e39bb93fc1d4c370ceb)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceFile", value)
 
@@ -334,14 +334,14 @@ class DataArchiveFile(
     @type.setter
     def type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFile, "type").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__60c0778b3789354f6804e1c1ce39630da6b9932c71223ea45e1bb6b723916262)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "type", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-archive.dataArchiveFile.DataArchiveFileConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -362,23 +362,23 @@ class DataArchiveFile(
         "source_file": "sourceFile",
     },
 )
-class DataArchiveFileConfig(cdktf.TerraformMetaArguments):
+class DataArchiveFileConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         output_path: builtins.str,
         type: builtins.str,
         excludes: typing.Optional[typing.Sequence[builtins.str]] = None,
         id: typing.Optional[builtins.str] = None,
         output_file_mode: typing.Optional[builtins.str] = None,
-        source: typing.Optional[typing.Union[cdktf.IResolvable, typing.Sequence[typing.Union["DataArchiveFileSource", typing.Dict[str, typing.Any]]]]] = None,
+        source: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union["DataArchiveFileSource", typing.Dict[builtins.str, typing.Any]]]]] = None,
         source_content: typing.Optional[builtins.str] = None,
         source_content_filename: typing.Optional[builtins.str] = None,
         source_dir: typing.Optional[builtins.str] = None,
@@ -404,9 +404,9 @@ class DataArchiveFileConfig(cdktf.TerraformMetaArguments):
         :param source_file: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#source_file DataArchiveFile#source_file}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(DataArchiveFileConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__395d6c956a8f6a157e1bf9db0b880a72f8d80755220480442d2acbff968ca74f)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -424,7 +424,7 @@ class DataArchiveFileConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument source_content_filename", value=source_content_filename, expected_type=type_hints["source_content_filename"])
             check_type(argname="argument source_dir", value=source_dir, expected_type=type_hints["source_dir"])
             check_type(argname="argument source_file", value=source_file, expected_type=type_hints["source_file"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "output_path": output_path,
             "type": type,
         }
@@ -462,12 +462,12 @@ class DataArchiveFileConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -478,46 +478,48 @@ class DataArchiveFileConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def output_path(self) -> builtins.str:
@@ -558,13 +560,13 @@ class DataArchiveFileConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def source(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataArchiveFileSource"]]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["DataArchiveFileSource"]]]:
         '''source block.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#source DataArchiveFile#source}
         '''
         result = self._values.get("source")
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List["DataArchiveFileSource"]]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List["DataArchiveFileSource"]]], result)
 
     @builtins.property
     def source_content(self) -> typing.Optional[builtins.str]:
@@ -614,10 +616,10 @@ class DataArchiveFileSource:
         :param filename: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/d/file#filename DataArchiveFile#filename}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataArchiveFileSource.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__5904c5461679cf6f1f619fb8bf2ab9cf44afa5adb738fa7a85022f5f3df3fa5b)
             check_type(argname="argument content", value=content, expected_type=type_hints["content"])
             check_type(argname="argument filename", value=filename, expected_type=type_hints["filename"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "content": content,
             "filename": filename,
         }
@@ -649,13 +651,13 @@ class DataArchiveFileSource:
 
 
 class DataArchiveFileSourceList(
-    cdktf.ComplexList,
+    _cdktf_9a9027ec.ComplexList,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-archive.dataArchiveFile.DataArchiveFileSourceList",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         wraps_set: builtins.bool,
     ) -> None:
@@ -665,7 +667,7 @@ class DataArchiveFileSourceList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataArchiveFileSourceList.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__88a478b72b8e8d3138dbcc97340cac916ce14a6ffea6dcc31af91669013d567f)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -677,7 +679,7 @@ class DataArchiveFileSourceList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataArchiveFileSourceList.get)
+            type_hints = typing.get_type_hints(_typecheckingstub__3db9d94aea08c3bdc2cca23e3649df8e1c5463390f53f0bbbcede6dee2eac5d8)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("DataArchiveFileSourceOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -690,20 +692,20 @@ class DataArchiveFileSourceList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFileSourceList, "_terraform_attribute").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7d969f8d3a7e5efbd20dff84d65fa9b0b38f7d611603684a884c5428bea6fc2d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
     @builtins.property
     @jsii.member(jsii_name="terraformResource")
-    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
+    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
         '''The parent resource.'''
-        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))
+        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))
 
     @_terraform_resource.setter
-    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
+    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFileSourceList, "_terraform_resource").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__0a03dc94d13173c2918de795b846220520d863e45e28a2261aba13df1c3ce1be)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -716,7 +718,7 @@ class DataArchiveFileSourceList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFileSourceList, "_wraps_set").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b28112c47e238306e0bab024eb02c6bb5507f1a3c32e6e8989594831c5ae16f2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -724,28 +726,28 @@ class DataArchiveFileSourceList(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataArchiveFileSource]]]:
-        return typing.cast(typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataArchiveFileSource]]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[DataArchiveFileSource]]]:
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[DataArchiveFileSource]]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[cdktf.IResolvable, typing.List[DataArchiveFileSource]]],
+        value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[DataArchiveFileSource]]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFileSourceList, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d17689ad2b65c75353ee71da6eb42a0dc15d46d1bb15a55d37262a6c529abb45)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
 
 class DataArchiveFileSourceOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-archive.dataArchiveFile.DataArchiveFileSourceOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         complex_object_index: jsii.Number,
         complex_object_is_from_set: builtins.bool,
@@ -757,7 +759,7 @@ class DataArchiveFileSourceOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataArchiveFileSourceOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__104762102aeec1438fe2a86c64c84c2f5a8a4a5cbdf8451e8b6ecdda38d0394d)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -782,7 +784,7 @@ class DataArchiveFileSourceOutputReference(
     @content.setter
     def content(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFileSourceOutputReference, "content").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__31aec45310cdcf623c915cf360d129eae107e050394d784d0d9359096924d572)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "content", value)
 
@@ -794,7 +796,7 @@ class DataArchiveFileSourceOutputReference(
     @filename.setter
     def filename(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFileSourceOutputReference, "filename").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__dbbf017c25c7cdf0d4de3e08d2ef9b67870fe102ed7e2403c21a798c5c1bfb6a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "filename", value)
 
@@ -802,16 +804,16 @@ class DataArchiveFileSourceOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[DataArchiveFileSource, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[DataArchiveFileSource, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[DataArchiveFileSource, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[DataArchiveFileSource, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[DataArchiveFileSource, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[DataArchiveFileSource, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataArchiveFileSourceOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8fc6924f9fc21231348b7a9b6caf4050cbb99f5ab9bdcb76e627f9583bcc0a6a)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -825,3 +827,184 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__3f8174f229f3604133f5c77a80cd25d2977aef1687fff32139249b73dce43cf7(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    output_path: builtins.str,
+    type: builtins.str,
+    excludes: typing.Optional[typing.Sequence[builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    output_file_mode: typing.Optional[builtins.str] = None,
+    source: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[DataArchiveFileSource, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    source_content: typing.Optional[builtins.str] = None,
+    source_content_filename: typing.Optional[builtins.str] = None,
+    source_dir: typing.Optional[builtins.str] = None,
+    source_file: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d003f85638c28bffbd4441abb65c0dc94b23f40ab53f06c48a8d24b28d5f42be(
+    value: typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[DataArchiveFileSource, typing.Dict[builtins.str, typing.Any]]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__20c4285397b574ace2586d5b7d9c0efed97c37db7016848d04cb03aa64878453(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__432198c6c939e380c074357e6b59c80d61ade9150c5df2056d07049c2715bcf6(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5cf0d3fbf6707bec587f4a960cd54edd8e60f917d78b8b942cc183e29c7291d2(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3592643f4a565fac9e7ff8c5189ac2f818943f620f705989325f0070d0f74749(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d4f7f1c2a67ef2d6cd3380e72c2663d13a07e8a175ff5a4cf7f68c4df802c472(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__26ddff38facb63d2db815fde82cff0e0559b482fd07b09a7c023eac38911966c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__f9dfe185d1160c0d01df7661702ee3e6ce0223ba9ffbf6fe85f7c82315c1702f(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0cb49ee8a8a77e542ce50503f7116ae685411f0a635d0e39bb93fc1d4c370ceb(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__60c0778b3789354f6804e1c1ce39630da6b9932c71223ea45e1bb6b723916262(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__395d6c956a8f6a157e1bf9db0b880a72f8d80755220480442d2acbff968ca74f(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    output_path: builtins.str,
+    type: builtins.str,
+    excludes: typing.Optional[typing.Sequence[builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    output_file_mode: typing.Optional[builtins.str] = None,
+    source: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.Sequence[typing.Union[DataArchiveFileSource, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    source_content: typing.Optional[builtins.str] = None,
+    source_content_filename: typing.Optional[builtins.str] = None,
+    source_dir: typing.Optional[builtins.str] = None,
+    source_file: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5904c5461679cf6f1f619fb8bf2ab9cf44afa5adb738fa7a85022f5f3df3fa5b(
+    *,
+    content: builtins.str,
+    filename: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__88a478b72b8e8d3138dbcc97340cac916ce14a6ffea6dcc31af91669013d567f(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    wraps_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__3db9d94aea08c3bdc2cca23e3649df8e1c5463390f53f0bbbcede6dee2eac5d8(
+    index: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7d969f8d3a7e5efbd20dff84d65fa9b0b38f7d611603684a884c5428bea6fc2d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__0a03dc94d13173c2918de795b846220520d863e45e28a2261aba13df1c3ce1be(
+    value: _cdktf_9a9027ec.IInterpolatingParent,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b28112c47e238306e0bab024eb02c6bb5507f1a3c32e6e8989594831c5ae16f2(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d17689ad2b65c75353ee71da6eb42a0dc15d46d1bb15a55d37262a6c529abb45(
+    value: typing.Optional[typing.Union[_cdktf_9a9027ec.IResolvable, typing.List[DataArchiveFileSource]]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__104762102aeec1438fe2a86c64c84c2f5a8a4a5cbdf8451e8b6ecdda38d0394d(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    complex_object_index: jsii.Number,
+    complex_object_is_from_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__31aec45310cdcf623c915cf360d129eae107e050394d784d0d9359096924d572(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__dbbf017c25c7cdf0d4de3e08d2ef9b67870fe102ed7e2403c21a798c5c1bfb6a(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8fc6924f9fc21231348b7a9b6caf4050cbb99f5ab9bdcb76e627f9583bcc0a6a(
+    value: typing.Optional[typing.Union[DataArchiveFileSource, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
