@@ -17,12 +17,12 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class File(
-    cdktf.TerraformResource,
+    _cdktf_9a9027ec.TerraformResource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-archive.file.File",
 ):
@@ -30,7 +30,7 @@ class File(
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         output_path: builtins.str,
@@ -38,18 +38,18 @@ class File(
         excludes: typing.Optional[typing.Sequence[builtins.str]] = None,
         id: typing.Optional[builtins.str] = None,
         output_file_mode: typing.Optional[builtins.str] = None,
-        source: typing.Optional[typing.Union[typing.Sequence[typing.Union["FileSource", typing.Dict[str, typing.Any]]], cdktf.IResolvable]] = None,
+        source: typing.Optional[typing.Union[typing.Sequence[typing.Union["FileSource", typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable]] = None,
         source_content: typing.Optional[builtins.str] = None,
         source_content_filename: typing.Optional[builtins.str] = None,
         source_dir: typing.Optional[builtins.str] = None,
         source_file: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
         '''Create a new {@link https://www.terraform.io/docs/providers/archive/r/file archive_file} Resource.
 
@@ -74,7 +74,7 @@ class File(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(File.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__ffa9a1e310e0fed84f9ce7cadd39e4c006e02fc1451a79fc6f283c6e1f9bd7c1)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = FileConfig(
@@ -102,13 +102,13 @@ class File(
     @jsii.member(jsii_name="putSource")
     def put_source(
         self,
-        value: typing.Union[typing.Sequence[typing.Union["FileSource", typing.Dict[str, typing.Any]]], cdktf.IResolvable],
+        value: typing.Union[typing.Sequence[typing.Union["FileSource", typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable],
     ) -> None:
         '''
         :param value: -
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(File.put_source)
+            type_hints = typing.get_type_hints(_typecheckingstub__a50c420f409a76db13cab937bd8f16a960a6716abc4dbd523bbb8b76ec1df579)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         return typing.cast(None, jsii.invoke(self, "putSource", [value]))
 
@@ -222,8 +222,8 @@ class File(
     @jsii.member(jsii_name="sourceInput")
     def source_input(
         self,
-    ) -> typing.Optional[typing.Union[typing.List["FileSource"], cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[typing.List["FileSource"], cdktf.IResolvable]], jsii.get(self, "sourceInput"))
+    ) -> typing.Optional[typing.Union[typing.List["FileSource"], _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[typing.List["FileSource"], _cdktf_9a9027ec.IResolvable]], jsii.get(self, "sourceInput"))
 
     @builtins.property
     @jsii.member(jsii_name="typeInput")
@@ -238,7 +238,7 @@ class File(
     @excludes.setter
     def excludes(self, value: typing.List[builtins.str]) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(File, "excludes").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__7797e5908778c373a4181c51cf5bc07966c3d6d42e2c81354904354c289b140d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "excludes", value)
 
@@ -250,7 +250,7 @@ class File(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(File, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__60049b2a0ecafa111d2aa8b21d1c665b883c141b39432553aa7a2918f237814c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -262,7 +262,7 @@ class File(
     @output_file_mode.setter
     def output_file_mode(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(File, "output_file_mode").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__79807569b50d474ed25e61d3183471ceccafe0ac9a335d23e8029877e20d5b8e)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "outputFileMode", value)
 
@@ -274,7 +274,7 @@ class File(
     @output_path.setter
     def output_path(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(File, "output_path").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8b96d34815e85a1bca3a705cde1b0b5ebf49ddc55fd930c516553cd449b41c00)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "outputPath", value)
 
@@ -286,7 +286,7 @@ class File(
     @source_content.setter
     def source_content(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(File, "source_content").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__5f58861d10def400c6cefa28dc3116c759670ad26f8efaffe5bdb10effa68ca1)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceContent", value)
 
@@ -298,7 +298,7 @@ class File(
     @source_content_filename.setter
     def source_content_filename(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(File, "source_content_filename").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e5df5fac04fbbfc6fb5d16c938175736ed88c32c346df61aa4076379b79769cb)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceContentFilename", value)
 
@@ -310,7 +310,7 @@ class File(
     @source_dir.setter
     def source_dir(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(File, "source_dir").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__ac996a29eb7f03ed3bd3d76e8b064ff4d36277662c40c93e24a6cc5397f9b671)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceDir", value)
 
@@ -322,7 +322,7 @@ class File(
     @source_file.setter
     def source_file(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(File, "source_file").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__caf74dbe1729274c07b4de1baed6c0429f583d632d7dbe48e57875125e595d5c)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "sourceFile", value)
 
@@ -334,14 +334,14 @@ class File(
     @type.setter
     def type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(File, "type").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8d8e35a814ac61391f0619191308b0b508619e8f4686f897a4dbf41e4381dd47)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "type", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-archive.file.FileConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -362,23 +362,23 @@ class File(
         "source_file": "sourceFile",
     },
 )
-class FileConfig(cdktf.TerraformMetaArguments):
+class FileConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
         count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         output_path: builtins.str,
         type: builtins.str,
         excludes: typing.Optional[typing.Sequence[builtins.str]] = None,
         id: typing.Optional[builtins.str] = None,
         output_file_mode: typing.Optional[builtins.str] = None,
-        source: typing.Optional[typing.Union[typing.Sequence[typing.Union["FileSource", typing.Dict[str, typing.Any]]], cdktf.IResolvable]] = None,
+        source: typing.Optional[typing.Union[typing.Sequence[typing.Union["FileSource", typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable]] = None,
         source_content: typing.Optional[builtins.str] = None,
         source_content_filename: typing.Optional[builtins.str] = None,
         source_dir: typing.Optional[builtins.str] = None,
@@ -404,9 +404,9 @@ class FileConfig(cdktf.TerraformMetaArguments):
         :param source_file: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/r/file#source_file File#source_file}.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(FileConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__4cf416deaa089a02b7fc630d948296d45144383aef1cde25d0742ca6c4454dd4)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -424,7 +424,7 @@ class FileConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument source_content_filename", value=source_content_filename, expected_type=type_hints["source_content_filename"])
             check_type(argname="argument source_dir", value=source_dir, expected_type=type_hints["source_dir"])
             check_type(argname="argument source_file", value=source_file, expected_type=type_hints["source_file"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "output_path": output_path,
             "type": type,
         }
@@ -462,12 +462,12 @@ class FileConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
     def count(self) -> typing.Optional[jsii.Number]:
@@ -478,46 +478,48 @@ class FileConfig(cdktf.TerraformMetaArguments):
         return typing.cast(typing.Optional[jsii.Number], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def output_path(self) -> builtins.str:
@@ -558,13 +560,13 @@ class FileConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def source(
         self,
-    ) -> typing.Optional[typing.Union[typing.List["FileSource"], cdktf.IResolvable]]:
+    ) -> typing.Optional[typing.Union[typing.List["FileSource"], _cdktf_9a9027ec.IResolvable]]:
         '''source block.
 
         Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/r/file#source File#source}
         '''
         result = self._values.get("source")
-        return typing.cast(typing.Optional[typing.Union[typing.List["FileSource"], cdktf.IResolvable]], result)
+        return typing.cast(typing.Optional[typing.Union[typing.List["FileSource"], _cdktf_9a9027ec.IResolvable]], result)
 
     @builtins.property
     def source_content(self) -> typing.Optional[builtins.str]:
@@ -614,10 +616,10 @@ class FileSource:
         :param filename: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/archive/r/file#filename File#filename}.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FileSource.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__b11194e55a06bbf9bdba900600d77ae8dc999b8147683c454f2452321f3945f3)
             check_type(argname="argument content", value=content, expected_type=type_hints["content"])
             check_type(argname="argument filename", value=filename, expected_type=type_hints["filename"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "content": content,
             "filename": filename,
         }
@@ -649,13 +651,13 @@ class FileSource:
 
 
 class FileSourceList(
-    cdktf.ComplexList,
+    _cdktf_9a9027ec.ComplexList,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-archive.file.FileSourceList",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         wraps_set: builtins.bool,
     ) -> None:
@@ -665,7 +667,7 @@ class FileSourceList(
         :param wraps_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FileSourceList.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__2b12af409262dff94ca6a6cd8a1b08c71d07b915e5745a2894f5aa5e29a3167b)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument wraps_set", value=wraps_set, expected_type=type_hints["wraps_set"])
@@ -677,7 +679,7 @@ class FileSourceList(
         :param index: the index of the item to return.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FileSourceList.get)
+            type_hints = typing.get_type_hints(_typecheckingstub__ebffd8d3bf5bb5507e9c5841f3315f32c7cbd88ee83fa6ebd53d62f38d0db605)
             check_type(argname="argument index", value=index, expected_type=type_hints["index"])
         return typing.cast("FileSourceOutputReference", jsii.invoke(self, "get", [index]))
 
@@ -690,20 +692,20 @@ class FileSourceList(
     @_terraform_attribute.setter
     def _terraform_attribute(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FileSourceList, "_terraform_attribute").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e17716d76a6f98bedad48ec192a8aac797794fa7939ca64368eb2d9bbc964035)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformAttribute", value)
 
     @builtins.property
     @jsii.member(jsii_name="terraformResource")
-    def _terraform_resource(self) -> cdktf.IInterpolatingParent:
+    def _terraform_resource(self) -> _cdktf_9a9027ec.IInterpolatingParent:
         '''The parent resource.'''
-        return typing.cast(cdktf.IInterpolatingParent, jsii.get(self, "terraformResource"))
+        return typing.cast(_cdktf_9a9027ec.IInterpolatingParent, jsii.get(self, "terraformResource"))
 
     @_terraform_resource.setter
-    def _terraform_resource(self, value: cdktf.IInterpolatingParent) -> None:
+    def _terraform_resource(self, value: _cdktf_9a9027ec.IInterpolatingParent) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FileSourceList, "_terraform_resource").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__13bf4702f620140aeb41a004039789525b09d1a03a34a68cea9c28e8b1167183)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "terraformResource", value)
 
@@ -716,7 +718,7 @@ class FileSourceList(
     @_wraps_set.setter
     def _wraps_set(self, value: builtins.bool) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FileSourceList, "_wraps_set").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__054ee919fefa8e8d55d5535984746684f261fde847ee427f26d3284cfc14f309)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "wrapsSet", value)
 
@@ -724,28 +726,28 @@ class FileSourceList(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[typing.List[FileSource], cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[typing.List[FileSource], cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[typing.List[FileSource], _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[typing.List[FileSource], _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[typing.List[FileSource], cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[typing.List[FileSource], _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FileSourceList, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__63dc9e7bd3b8e8b0a0c8634914d15010d2e2cfaab364a3bc4de880d005ea84c2)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
 
 class FileSourceOutputReference(
-    cdktf.ComplexObject,
+    _cdktf_9a9027ec.ComplexObject,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-archive.file.FileSourceOutputReference",
 ):
     def __init__(
         self,
-        terraform_resource: cdktf.IInterpolatingParent,
+        terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
         terraform_attribute: builtins.str,
         complex_object_index: jsii.Number,
         complex_object_is_from_set: builtins.bool,
@@ -757,7 +759,7 @@ class FileSourceOutputReference(
         :param complex_object_is_from_set: whether the list is wrapping a set (will add tolist() to be able to access an item via an index).
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(FileSourceOutputReference.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__53122ab2bbcfabc5e5e696a74bf00cc9c8ec91e86193cf0c6c3f5bcf03cd99af)
             check_type(argname="argument terraform_resource", value=terraform_resource, expected_type=type_hints["terraform_resource"])
             check_type(argname="argument terraform_attribute", value=terraform_attribute, expected_type=type_hints["terraform_attribute"])
             check_type(argname="argument complex_object_index", value=complex_object_index, expected_type=type_hints["complex_object_index"])
@@ -782,7 +784,7 @@ class FileSourceOutputReference(
     @content.setter
     def content(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FileSourceOutputReference, "content").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__11b997b0fade71031b2cd81f37232c54b0a30677cf23e1f7a48a3b99e881caf3)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "content", value)
 
@@ -794,7 +796,7 @@ class FileSourceOutputReference(
     @filename.setter
     def filename(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FileSourceOutputReference, "filename").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__8349ec8bdd2ec3d8cff381f06ce37e562a70035d6a4c71b85caa6e883ec7fd7d)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "filename", value)
 
@@ -802,16 +804,16 @@ class FileSourceOutputReference(
     @jsii.member(jsii_name="internalValue")
     def internal_value(
         self,
-    ) -> typing.Optional[typing.Union[FileSource, cdktf.IResolvable]]:
-        return typing.cast(typing.Optional[typing.Union[FileSource, cdktf.IResolvable]], jsii.get(self, "internalValue"))
+    ) -> typing.Optional[typing.Union[FileSource, _cdktf_9a9027ec.IResolvable]]:
+        return typing.cast(typing.Optional[typing.Union[FileSource, _cdktf_9a9027ec.IResolvable]], jsii.get(self, "internalValue"))
 
     @internal_value.setter
     def internal_value(
         self,
-        value: typing.Optional[typing.Union[FileSource, cdktf.IResolvable]],
+        value: typing.Optional[typing.Union[FileSource, _cdktf_9a9027ec.IResolvable]],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(FileSourceOutputReference, "internal_value").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d230643d14de1a8beb8dce496488449596aab0920e5f210a79557b2a27dc4323)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "internalValue", value)
 
@@ -825,3 +827,184 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__ffa9a1e310e0fed84f9ce7cadd39e4c006e02fc1451a79fc6f283c6e1f9bd7c1(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    output_path: builtins.str,
+    type: builtins.str,
+    excludes: typing.Optional[typing.Sequence[builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    output_file_mode: typing.Optional[builtins.str] = None,
+    source: typing.Optional[typing.Union[typing.Sequence[typing.Union[FileSource, typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable]] = None,
+    source_content: typing.Optional[builtins.str] = None,
+    source_content_filename: typing.Optional[builtins.str] = None,
+    source_dir: typing.Optional[builtins.str] = None,
+    source_file: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__a50c420f409a76db13cab937bd8f16a960a6716abc4dbd523bbb8b76ec1df579(
+    value: typing.Union[typing.Sequence[typing.Union[FileSource, typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7797e5908778c373a4181c51cf5bc07966c3d6d42e2c81354904354c289b140d(
+    value: typing.List[builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__60049b2a0ecafa111d2aa8b21d1c665b883c141b39432553aa7a2918f237814c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__79807569b50d474ed25e61d3183471ceccafe0ac9a335d23e8029877e20d5b8e(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8b96d34815e85a1bca3a705cde1b0b5ebf49ddc55fd930c516553cd449b41c00(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__5f58861d10def400c6cefa28dc3116c759670ad26f8efaffe5bdb10effa68ca1(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e5df5fac04fbbfc6fb5d16c938175736ed88c32c346df61aa4076379b79769cb(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ac996a29eb7f03ed3bd3d76e8b064ff4d36277662c40c93e24a6cc5397f9b671(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__caf74dbe1729274c07b4de1baed6c0429f583d632d7dbe48e57875125e595d5c(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8d8e35a814ac61391f0619191308b0b508619e8f4686f897a4dbf41e4381dd47(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__4cf416deaa089a02b7fc630d948296d45144383aef1cde25d0742ca6c4454dd4(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[jsii.Number] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    output_path: builtins.str,
+    type: builtins.str,
+    excludes: typing.Optional[typing.Sequence[builtins.str]] = None,
+    id: typing.Optional[builtins.str] = None,
+    output_file_mode: typing.Optional[builtins.str] = None,
+    source: typing.Optional[typing.Union[typing.Sequence[typing.Union[FileSource, typing.Dict[builtins.str, typing.Any]]], _cdktf_9a9027ec.IResolvable]] = None,
+    source_content: typing.Optional[builtins.str] = None,
+    source_content_filename: typing.Optional[builtins.str] = None,
+    source_dir: typing.Optional[builtins.str] = None,
+    source_file: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b11194e55a06bbf9bdba900600d77ae8dc999b8147683c454f2452321f3945f3(
+    *,
+    content: builtins.str,
+    filename: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2b12af409262dff94ca6a6cd8a1b08c71d07b915e5745a2894f5aa5e29a3167b(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    wraps_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__ebffd8d3bf5bb5507e9c5841f3315f32c7cbd88ee83fa6ebd53d62f38d0db605(
+    index: jsii.Number,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e17716d76a6f98bedad48ec192a8aac797794fa7939ca64368eb2d9bbc964035(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__13bf4702f620140aeb41a004039789525b09d1a03a34a68cea9c28e8b1167183(
+    value: _cdktf_9a9027ec.IInterpolatingParent,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__054ee919fefa8e8d55d5535984746684f261fde847ee427f26d3284cfc14f309(
+    value: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__63dc9e7bd3b8e8b0a0c8634914d15010d2e2cfaab364a3bc4de880d005ea84c2(
+    value: typing.Optional[typing.Union[typing.List[FileSource], _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__53122ab2bbcfabc5e5e696a74bf00cc9c8ec91e86193cf0c6c3f5bcf03cd99af(
+    terraform_resource: _cdktf_9a9027ec.IInterpolatingParent,
+    terraform_attribute: builtins.str,
+    complex_object_index: jsii.Number,
+    complex_object_is_from_set: builtins.bool,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__11b997b0fade71031b2cd81f37232c54b0a30677cf23e1f7a48a3b99e881caf3(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__8349ec8bdd2ec3d8cff381f06ce37e562a70035d6a4c71b85caa6e883ec7fd7d(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d230643d14de1a8beb8dce496488449596aab0920e5f210a79557b2a27dc4323(
+    value: typing.Optional[typing.Union[FileSource, _cdktf_9a9027ec.IResolvable]],
+) -> None:
+    """Type checking stubs"""
+    pass
